@@ -2,17 +2,11 @@ import numpy as np
 #from scipy.fftpack import fft,ifft
 from numpy.fft import fft,ifft
 import matplotlib.pyplot as plt
-import time
-import math
-import librosa
-from nsgt import NSGT, LogScale, LinScale, MelScale, OctScale
-<<<<<<< HEAD
-from audio_proc_test import *
-=======
->>>>>>> 
 import pywt
 import scipy.signal
 from scipy import signal
+from audio_proc_functions import *
+from nsgt import NSGT, LogScale, LinScale, MelScale, OctScale
 #from constant_q_FB import create_filters
 import time
 
